/**
 * The <code>LinkList</code> class is an implementation
 * of the doubly linked list abstract data type.
 * <p>
 * This class provides methods for constructing, inserting keys into,
 * and printing a list.  See the Node class.
 *
 * @author  Somesh Jha
 * @author  Jeff Stephenson
 */


public class LinkList 
{

    /**
     * The (Node) head of the list
     */
    Node head;

    /**
     * A (boolean) flag value used for debugging
     */
    static final boolean DEBUG=false;

    /**
     * Constructs a LinkList object, initially the 
     * list will be empty (head == null)
     *
     */
    public LinkList() 
    {
        head = null;
    }


    /**
     * Inserts a new node into the list with the key data
     * if a node with equal key data does not already exist
     *
     * @param   k			the (Key) data to insert
     */
    public Node Insert(KeyInterface k) 
    {
        if (DEBUG) 
        {
            System.out.print("Inserting node with key: ");
            k.printKey();
        }
        
        Node x;
        if (head == null) 
        {
            x = new Node(k);
            head=x;
        }
        else 
        {
            x = head.InsertElement(k);
        }
        
        return(x);
    }


    /**
     * Prints the LinkList Object
     *
     * @exception LinkListException Thrown when the linked-list is empty.
     */
    public void printList() throws LinkListException 
    {
        if (head == null) 
        {
            throw new LinkListException("Printing an empty list");
        }
        else 
        {
            System.out.println("-----------------BEGIN-----------------------");
            head.printNode();
            System.out.println("-----------------END-----------------------");
        }
    }


}
  
  
